@@ -44,12 +44,18 @@ DATAGROWTH_DEFAULT_CONFIGURATION = getattr(settings, "DATAGROWTH_DEFAULT_CONFIGU
     "global_purge_immediately": False,  # by default keep resources around
     "global_sample_size": 0,
     "global_cache_only": False,
+    "global_pipeline_app_label": None,
+    "global_pipeline_models": {
+        "document": "Document",
+        "process_result": "ProcessResult",
+        "batch": "Batch"
+    },
 
     "http_resource_continuation_limit": 1,
     "http_resource_interval_duration": 0,  # NB: milliseconds!
     "http_resource_concat_args_size": 0,
     "http_resource_concat_args_symbol": "|",
-    "global_backoff_delays": [8, 16, 32, 64, 128],
+    "global_backoff_delays": [2, 4, 8, 16],
 
     "wikipedia_wiki_country": "en",
     "wikipedia_wiki_query_param": "titles",
